# OLVM Engine backup/restore scripts

This directory contains shell scripts that can be used to automate the OLVM Engine backups and restoration.

1. **olvm_backup.sh** - backup the OLVM engine and copy the file to a cloud storage bucket.
2. **olvm_restore.sh** - restore OLVM engine from a backup
3. **daily_olvm_crontab.txt**  - crontab entry to schedule olvm_backup_daily.sh to run at 00:00 once a day
4. **download_olvmbkps_fromgcs.sh** - this script to download OLVM backup files from object store GCS to local disk on particular folder

The `olvm_backup.sh` script is designed to be included in a crontab as shown in the `daily_olvm_crontab.txt` file. It calls the `engine-backup` command to backup the OLVM engine and then uploads the backup to a cloud storage bucket. The script deletes backups on local disk that are more than 3 days old. Older backups are retained in the storage bucket. Global variables at the beginning of the script are used to control file locations. These should be edited before use.

## Setup Instructions

OLVM Engine DR plan uses a combination of shell scripts and disk snapshots to protect environment metadata.

### Shell script installation

1. Create a Cloud Storage bucket to store your backups using  terminal using below command (substituting your own storage bucket name):
    ```
    gsutil mb -c nearline -l us gs://olvm-backup
    ```
2. Create a service account to write backup files to Cloud Storage using below command:
    ```
    gcloud iam service-accounts create ora-backup-olvm
    ```
3. Give the service account admin access to Cloud Storage (substituting your own storage project and service account names):
    ```
    gcloud projects add-iam-policy-binding  dito-oracle-migration-dev \
     --member "serviceAccount:ora-backup-olvm@dito-oracle-migration-dev.iam.gserviceaccount.com" \
     --role "roles/storage.objectAdmin"
    ```
4. SSH into the VM and use `sudo -s` to become root
5. Download the service account keys  (substituting your own service account name):
    ```
    gcloud iam service-accounts keys create ora-backup-olvm.json \
        --iam-account=ora-backup-olvm@dito-oracle-migration-dev.iam.gserviceaccount.com
    ```
6. Configure the gsutil command-line tool on the vm
    ```
    gcloud auth activate-service-account --key-file ./ora-backup-olvm.json
    ```
7. Edit the global variables in the `olvm_backup_daily.sh` script
8. Schedule a cron job to call olvm_backup_daily.sh
9. Monitor the file system backup location and storage bucket for at least 4 days to verify the last 3 days of backup files are available locally and all backups are available in cloud storage.

### Scheduled snapshots

Scheduled snapshots are a mechanism provided in GCP to backup Compute Engine persistent disks. The OLVM Engine and its databases are contained on the boot disk of its VM. Follow the instructions in the [scheduled-snapshots](https://cloud.google.com/compute/docs/disks/scheduled-snapshots) documentation to schedule a regular backup of the disk.

Create a snapshot schedule with an 8 hour frequency and a 7 day retention period. Associate the schedule with the OLVM VM boot disk.

### Compute Engine settings

Use the Cloud Console UI to verify the following settings for the Compute Engine VM that the OLVM Engine is installed on.
- **Basic information** - `Deletion protection` is **Enabled**
- **Storage** - `When deleting instance` is set to **Keep disk**

## Usage instructions

See the `disaster-recovery-procedures.md` file in the docs directory