#!/bin/bash
# Backup OLVM Engine and copy result to a storage bucket.
# This scripts makes assumption this is running as a "root" user and
# a service account key has been installed to allow access to the
# storage bucket.

# Review/Edit base_path and storage bucket values before first run
BASE_PATH=/root/olvm-engine-backups
OLVM_BUCKET=gs://ora-backup-olvm/

echo "Setting up paths and file names"
BACKUP_FILE=${BASE_PATH}/latest/ovirt-engine-backup-`date +\%Y\%m\%d\-\%H\%M`
LOG_FILE=${BASE_PATH}/latest/ovirt-engine-backup-`date +\%Y\%m\%d\-\%H\%M`.log
STAGING_DIRECTORY=${BASE_PATH}/stage
LOCAL_BACKUPS=${BASE_PATH}/backups

echo "Verifing directories exist"
mkdir -p ${BASE_PATH}/latest
mkdir -p ${STAGING_DIRECTORY}
mkdir -p ${LOCAL_BACKUPS}

echo "Excuting olvm engine backup"
engine-backup --mode=backup --scope=all --file=${BACKUP_FILE} --log=${LOG_FILE}

echo "Moving backup files to staging directory"
mv ${BASE_PATH}/latest/* ${STAGING_DIRECTORY}

echo "Loading staged files to cloud storage bucket"
#upload daily backup files to nearline object storage location
gsutil -m cp -r ${STAGING_DIRECTORY}/*  ${OLVM_BUCKET}

echo "Moving staged files to backup directory"
#remove/delete daily file and log file staging directory after files are uploaded to gcs bucket
mv ${STAGING_DIRECTORY}/* ${LOCAL_BACKUPS}/

#command to remove anyfiles older than 3 days from local disk on the VM
echo "Removing old backups"
find ${LOCAL_BACKUPS}/ -mtime +2 | xargs -i rm {}


